==> haskell-test-framework-quickcheck2-0.3.0.5-17-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-test-framework-quickcheck2.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: test-framework-quickcheck2
version: 0.3.0.5
id: test-framework-quickcheck2-0.3.0.5-KkNvmQdA7EC7Quar44yBdQ
key: test-framework-quickcheck2-0.3.0.5-KkNvmQdA7EC7Quar44yBdQ
license: BSD-3-Clause
maintainer: Haskell Libraries <libraries@haskell.org>
author: Max Bolingbroke <batterseapower@hotmail.com>
homepage: http://haskell.github.io/test-framework/
synopsis: QuickCheck-2 support for the test-framework package.
description:
    Allows @QuickCheck-2@ properties to be used with the </package/test-framework test-framework package>.
category: Testing
abi: bed894fbcf3494c378196759a3bb8a68
exposed: True
exposed-modules:
    Test.Framework.Providers.QuickCheck2
import-dirs: /usr/lib/ghc-8.6.5/site-local/test-framework-quickcheck2-0.3.0.5
library-dirs: /usr/lib/ghc-8.6.5/site-local/test-framework-quickcheck2-0.3.0.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/test-framework-quickcheck2-0.3.0.5
hs-libraries: HStest-framework-quickcheck2-0.3.0.5-KkNvmQdA7EC7Quar44yBdQ
depends:
    QuickCheck-2.13.2-52gUk4jYsn5ItHsbXhjyg4 base-4.12.0.0
    extensible-exceptions-0.1.1.4-KI0dG6kQM84KnSzvR2Yb0
    random-1.1-3ypV4EIycgb35PKjTYYr5q
    test-framework-0.8.2.0-2dhLXXIyuWjLumyCVFTYFd
haddock-interfaces: /usr/share/doc/haskell-test-framework-quickcheck2/html/test-framework-quickcheck2.haddock
haddock-html: /usr/share/doc/haskell-test-framework-quickcheck2/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-test-framework-quickcheck2-0.3.0.5-19-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-test-framework-quickcheck2.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: test-framework-quickcheck2
version: 0.3.0.5
id: test-framework-quickcheck2-0.3.0.5-FmpToRhNC714zGRPrDgdqN
key: test-framework-quickcheck2-0.3.0.5-FmpToRhNC714zGRPrDgdqN
license: BSD-3-Clause
maintainer: Haskell Libraries <libraries@haskell.org>
author: Max Bolingbroke <batterseapower@hotmail.com>
homepage: http://haskell.github.io/test-framework/
synopsis: QuickCheck-2 support for the test-framework package.
description:
    Allows @QuickCheck-2@ properties to be used with the </package/test-framework test-framework package>.
category: Testing
abi: e2eb3bc3c3503c74e7080df377e91e6e
exposed: True
exposed-modules:
    Test.Framework.Providers.QuickCheck2
import-dirs: /usr/lib/ghc-8.6.5/site-local/test-framework-quickcheck2-0.3.0.5
library-dirs: /usr/lib/ghc-8.6.5/site-local/test-framework-quickcheck2-0.3.0.5
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/test-framework-quickcheck2-0.3.0.5
hs-libraries: HStest-framework-quickcheck2-0.3.0.5-FmpToRhNC714zGRPrDgdqN
depends:
    QuickCheck-2.13.2-KEVEjFnAQhp2P6vBjviJXi base-4.12.0.0
    extensible-exceptions-0.1.1.4-KI0dG6kQM84KnSzvR2Yb0
    random-1.1-3ypV4EIycgb35PKjTYYr5q
    test-framework-0.8.2.0-6VNxYg0rOQvC6zSsMyV1CA
haddock-interfaces: /usr/share/doc/haskell-test-framework-quickcheck2/html/test-framework-quickcheck2.haddock
haddock-html: /usr/share/doc/haskell-test-framework-quickcheck2/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
